@@ -634,7 +634,7 @@
       'layout': 'Blink',
       'name': 'Electron',
       'os': 'Windows 10 64-bit',
-      'process': { 
+      'process': {
         'versions': { 'electron': '1.4.5', 'node': '6.5.0' }
       },
       'version': '1.4.5'
@@ -1714,12 +1714,15 @@
       'version': '1.19'
     },
 
-    'Narwhal': (function() {
+    'Narwhal on Mac OS X 64-bit': (function() {
       var object = {
+        'environment': {},
         'exports': {},
+        'java': { 'lang': { 'System': { 'getProperty': function(property) { return /name/.test(property) ? 'Mac OS X' : 'x86_64'; } } } },
         'name': 'Narwhal',
+        'os': 'Mac OS X 64-bit',
         'require': function() {},
-        'system':  {}
+        'system':  { 'os': 'Mac OS X' }
       };
       object.global = object.system.global = object;
       return object;
@@ -1743,6 +1746,20 @@
       'version': '0.8.9'
     },
 
+    'Node.js 8.9.3 on Darwin 64-bit': {
+      'exports': {},
+      'global': {},
+      'name': 'Node.js',
+      'os': 'Darwin 64-bit',
+      'process': {
+        'arch': 'x64',
+        'version': 'v8.9.3',
+        'versions': { 'node': '8.9.3' },
+        'platform': 'darwin'
+      },
+      'version': '8.9.3'
+    },
+
     'Nokia Browser 8.5.0 (like Safari 5.x) on Nokia N9': {
       'ua': 'Mozilla/5.0 (MeeGo; NokiaN9) AppleWebKit/534.13 (KHTML, like Gecko) NokiaBrowser/8.5.0 Mobile Safari/534.13',
       'layout': 'WebKit',
@@ -1776,7 +1793,7 @@
       'layout': 'Blink',
       'name': 'NW.js',
       'os': 'Windows 10 64-bit',
-      'process': { 
+      'process': {
         'versions': { 'nw': '0.18.4', 'node': '7.0.0' }
       },
       'version': '0.18.4'
@@ -2008,18 +2025,21 @@
       'os': 'Linux i686'
     },
 
-    'Rhino on OS X 64-bit': {
+    'Rhino on Mac OS X 64-bit': {
       'environment': {},
       'global': {},
-      'java': { 'lang': { 'System': { 'getProperty': function(property) { return /name/.test(property) ? 'OS X' : 'x86_64'; } } } },
+      'java': { 'lang': { 'System': { 'getProperty': function(property) { return /name/.test(property) ? 'Mac OS X' : 'x86_64'; } } } },
       'name': 'Rhino',
-      'os': 'OS X 64-bit'
+      'os': 'Mac OS X 64-bit'
     },
 
-    'RingoJS 0.7': (function() {
+    'RingoJS 0.7 on Mac OS X 64-bit': (function() {
       var object = {
+        'environment': {},
         'exports': {},
+        'java': { 'lang': { 'System': { 'getProperty': function(property) { return /name/.test(property) ? 'Mac OS X' : 'x86_64'; } } } },
         'name': 'RingoJS',
+        'os': 'Mac OS X 64-bit',
         'require': function() { return { 'version': [0, 7] }; },
         'system':  {},
         'version': '0.7'
@@ -2028,6 +2048,20 @@
       return object;
     }()),
 
+    'RingoJS 1.2.1 on Mac OS X 64-bit': (function() {
+      var object = {
+        'environment': {},
+        'exports': {},
+        'java': { 'lang': { 'System': { 'getProperty': function(property) { return /name/.test(property) ? 'Mac OS X' : 'x86_64'; } } } },
+        'name': 'RingoJS',
+        'os': 'Mac OS X 64-bit',
+        'require': function() { return { 'version': [1, 2, 1] }; },
+        'version': '1.2.1'
+      };
+      object.global = object;
+      return object;
+    }()),
+
     'RockMelt 0.8.34.820 (like Chrome 6.0.472.63) on OS X 10.5.8': {
       'ua': 'Mozilla/5.0(Macintosh; U; Intel Mac OS X 10_5_8; en-US)AppleWebKit/534.3(KHTML,like Gecko)RockMelt/0.8.34.820 Chrome/6.0.472.63 Safari/534.3',
       'layout': 'WebKit',
@@ -2573,7 +2607,6 @@
   };
 
   /*--------------------------------------------------------------------------*/
-
   QUnit.module('platform' + (document ? '' : ': ' + platform));
 
   (function() {
